@@ -18,6 +18,8 @@ describe 'heat::engine' do
       :client_retry_limit                  => '<SERVICE DEFAULT>',
       :max_server_name_length              => '<SERVICE DEFAULT>',
       :max_interface_check_attempts        => '<SERVICE DEFAULT>',
+      :max_nova_api_microversion           => '<SERVICE DEFAULT>',
+      :max_ironic_api_microversion         => '<SERVICE DEFAULT>',
       :event_purge_batch_size              => '<SERVICE DEFAULT>',
       :max_events_per_stack                => '<SERVICE DEFAULT>',
       :stack_action_timeout                => '<SERVICE DEFAULT>',
@@ -29,11 +31,12 @@ describe 'heat::engine' do
       :max_nested_stack_depth              => '<SERVICE DEFAULT>',
       :plugin_dirs                         => '<SERVICE DEFAULT>',
       :server_keystone_endpoint_type       => '<SERVICE DEFAULT>',
+      :hidden_stack_tags                   => '<SERVICE DEFAULT>',
       :deferred_auth_method                => '<SERVICE DEFAULT>',
     }
   end
 
-  shared_examples_for 'heat-engine' do
+  shared_examples_for 'heat::engine' do
     let :pre_condition do
       "class { 'heat::keystone::authtoken':
          password => 'password',
@@ -41,13 +44,12 @@ describe 'heat::engine' do
     end
 
     [
-      {},
       { :auth_encryption_key                 => '1234567890AZERTYUIOPMLKJHGFDSQ12' },
       { :auth_encryption_key                 => '0234567890AZERTYUIOPMLKJHGFDSQ24',
         :enabled                             => false,
         :heat_stack_user_role                => 'heat_stack_user',
-        :heat_metadata_server_url            => 'http://127.0.0.1:8000',
-        :heat_waitcondition_server_url       => 'http://127.0.0.1:8000/v1/waitcondition',
+        :heat_metadata_server_url            => 'https://127.0.0.1:8000',
+        :heat_waitcondition_server_url       => 'https://127.0.0.1:8000/v1/waitcondition',
         :default_software_config_transport   => 'POLL_SERVER_CFN',
         :default_deployment_signal_transport => 'CFN_SIGNAL',
         :default_user_data_format            => 'HEAT_CFNTOOLS',
@@ -58,6 +60,8 @@ describe 'heat::engine' do
         :client_retry_limit                  => 2,
         :max_server_name_length              => 53,
         :max_interface_check_attempts        => 10,
+        :max_nova_api_microversion           => '2.30',
+        :max_ironic_api_microversion         => '1.20',
         :event_purge_batch_size              => 200,
         :max_events_per_stack                => 1000,
         :stack_action_timeout                => 3600,
@@ -67,8 +71,9 @@ describe 'heat::engine' do
         :convergence_engine                  => false,
         :environment_dir                     => '/etc/heat/environment.d',
         :template_dir                        => '/etc/heat/templates',
-        :client_retry_limit                  => 2,
+        :max_nested_stack_depth              => 3,
         :server_keystone_endpoint_type       => 'public',
+        :hidden_stack_tags                   => 'hidden',
         :deferred_auth_method                => 'trusts',
       }
     ].each do |new_params|
@@ -118,6 +123,8 @@ describe 'heat::engine' do
       it { is_expected.to contain_heat_config('DEFAULT/client_retry_limit').with_value( expected_params[:client_retry_limit] ) }
       it { is_expected.to contain_heat_config('DEFAULT/max_server_name_length').with_value( expected_params[:max_server_name_length] ) }
       it { is_expected.to contain_heat_config('DEFAULT/max_interface_check_attempts').with_value( expected_params[:max_interface_check_attempts] ) }
+      it { is_expected.to contain_heat_config('DEFAULT/max_nova_api_microversion').with_value( expected_params[:max_nova_api_microversion] ) }
+      it { is_expected.to contain_heat_config('DEFAULT/max_ironic_api_microversion').with_value( expected_params[:max_ironic_api_microversion] ) }
       it { is_expected.to contain_heat_config('DEFAULT/event_purge_batch_size').with_value( expected_params[:event_purge_batch_size] ) }
       it { is_expected.to contain_heat_config('DEFAULT/max_events_per_stack').with_value( expected_params[:max_events_per_stack] ) }
       it { is_expected.to contain_heat_config('DEFAULT/stack_action_timeout').with_value( expected_params[:stack_action_timeout] ) }
@@ -127,9 +134,10 @@ describe 'heat::engine' do
       it { is_expected.to contain_heat_config('DEFAULT/convergence_engine').with_value( expected_params[:convergence_engine] ) }
       it { is_expected.to contain_heat_config('DEFAULT/environment_dir').with_value( expected_params[:environment_dir] ) }
       it { is_expected.to contain_heat_config('DEFAULT/template_dir').with_value( expected_params[:template_dir] ) }
-      it { is_expected.to contain_heat_config('DEFAULT/plugin_dirs').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_heat_config('DEFAULT/client_retry_limit').with_value( expected_params[:client_retry_limit] ) }
+      it { is_expected.to contain_heat_config('DEFAULT/max_nested_stack_depth').with_value( expected_params[:max_nested_stack_depth] ) }
+      it { is_expected.to contain_heat_config('DEFAULT/plugin_dirs').with_value( expected_params[:plugin_dirs] ) }
       it { is_expected.to contain_heat_config('DEFAULT/server_keystone_endpoint_type').with_value( expected_params[:server_keystone_endpoint_type] ) }
+      it { is_expected.to contain_heat_config('DEFAULT/hidden_stack_tags').with_value( expected_params[:hidden_stack_tags] ) }
       it { is_expected.to contain_heat_config('DEFAULT/deferred_auth_method').with_value( expected_params[:deferred_auth_method] ) }
     end
 
@@ -160,20 +168,21 @@ describe 'heat::engine' do
       it { is_expected.to_not contain_service('heat-engine') }
     end
 
-    context 'with plugin_dirs value set' do
+    context 'with plugin_dirs set' do
       before do
         params.merge!({
           :plugin_dirs => ['/usr/lib/heat', '/usr/local/lib/heat'] })
       end
-      it { is_expected.to contain_heat_config('DEFAULT/plugin_dirs').with_value(['/usr/lib/heat,/usr/local/lib/heat']) }
+      it { is_expected.to contain_heat_config('DEFAULT/plugin_dirs').with_value('/usr/lib/heat,/usr/local/lib/heat') }
     end
 
-    context 'with wrong auth_encryption_key parameter size' do
+    context 'with hidden_stack_tags list' do
       before do
         params.merge!({
-          :auth_encryption_key => 'hello' })
+          :hidden_stack_tags => ['tag1', 'tag2'],
+        })
       end
-      it_raises 'a Puppet::Error', /5 is not a correct size for auth_encryption_key parameter, it must be either 16, 24, 32 bytes long./
+      it { is_expected.to contain_heat_config('DEFAULT/hidden_stack_tags').with_value('tag1,tag2') }
     end
   end
 
@@ -198,7 +207,7 @@ describe 'heat::engine' do
         end
       end
 
-      it_behaves_like 'heat-engine'
+      it_behaves_like 'heat::engine'
     end
   end
 
