@@ -40,13 +40,11 @@ describe 'heat' do
     it_configures 'with SSL enabled with kombu'
     it_configures 'with SSL enabled without kombu'
     it_configures 'with SSL disabled'
+    it_configures 'with region_name set'
+    it_configures 'without region_name set'
     it_configures 'with enable_stack_adopt and enable_stack_abandon set'
     it_configures 'with overridden messaging default parameters'
-    it_configures 'with notification_driver set to a string'
-
-    context 'with amqp messaging' do
-      it_configures 'amqp support'
-    end
+    it_configures 'with notification parameters'
   end
 
   shared_examples_for 'a heat base installation' do
@@ -92,6 +90,10 @@ describe 'heat' do
       is_expected.to contain_heat_config('DEFAULT/max_json_body_size').with_value('<SERVICE DEFAULT>')
     end
 
+    it 'configures template_fetch_timeout' do
+      is_expected.to contain_heat_config('DEFAULT/template_fetch_timeout').with_value('<SERVICE DEFAULT>')
+    end
+
     it 'configures keystone_ec2_uri' do
       is_expected.to contain_heat_config('ec2authtoken/auth_uri').with_value( '<SERVICE DEFAULT>' )
     end
@@ -110,7 +112,8 @@ describe 'heat' do
       is_expected.to contain_oslo__messaging__notifications('heat_config').with(
         :driver        => '<SERVICE DEFAULT>',
         :transport_url => '<SERVICE DEFAULT>',
-        :topics        => '<SERVICE DEFAULT>'
+        :topics        => '<SERVICE DEFAULT>',
+        :retry         => '<SERVICE DEFAULT>',
       )
     end
 
@@ -135,6 +138,7 @@ describe 'heat' do
         :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
         :heartbeat_rate                  => '<SERVICE DEFAULT>',
         :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+        :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
         :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
         :amqp_durable_queues             => '<SERVICE DEFAULT>',
         :rabbit_ha_queues                => '<SERVICE DEFAULT>',
@@ -143,6 +147,7 @@ describe 'heat' do
         :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+        :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
       )
     end
   end
@@ -165,6 +170,7 @@ describe 'heat' do
         :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
         :heartbeat_rate                  => '<SERVICE DEFAULT>',
         :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+        :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
         :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
         :amqp_durable_queues             => true,
         :rabbit_ha_queues                => true,
@@ -173,6 +179,7 @@ describe 'heat' do
         :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+        :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
       )
     end
   end
@@ -190,6 +197,7 @@ describe 'heat' do
         :heartbeat_timeout_threshold => '60',
         :heartbeat_rate              => '10',
         :heartbeat_in_pthread        => true,
+        :rabbit_qos_prefetch_count   => '<SERVICE DEFAULT>',
         :rabbit_use_ssl              => '<SERVICE DEFAULT>',
         :amqp_durable_queues         => '<SERVICE DEFAULT>',
         :rabbit_ha_queues            => '<SERVICE DEFAULT>',
@@ -304,12 +312,13 @@ describe 'heat' do
     end
   end
 
-  shared_examples_for 'with notification_driver set to a string' do
+  shared_examples_for 'with notification parameters' do
     before do
       params.merge!(
         :notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
         :notification_driver        => 'messagingv2',
         :notification_topics        => 'notifications',
+        :notification_retry         => 10,
       )
     end
 
@@ -317,63 +326,12 @@ describe 'heat' do
       is_expected.to contain_oslo__messaging__notifications('heat_config').with(
         :driver        => 'messagingv2',
         :transport_url => 'rabbit://rabbit_user:password@localhost:5673',
-        :topics        => 'notifications'
+        :topics        => 'notifications',
+        :retry         => 10,
       )
     end
   end
 
-  shared_examples_for 'amqp support' do
-    context 'with default parameters' do
-      it { is_expected.to contain_oslo__messaging__amqp('heat_config').with(
-        :server_request_prefix => '<SERVICE DEFAULT>',
-        :broadcast_prefix      => '<SERVICE DEFAULT>',
-        :group_request_prefix  => '<SERVICE DEFAULT>',
-        :container_name        => '<SERVICE DEFAULT>',
-        :idle_timeout          => '<SERVICE DEFAULT>',
-        :trace                 => '<SERVICE DEFAULT>',
-        :ssl_ca_file           => '<SERVICE DEFAULT>',
-        :ssl_cert_file         => '<SERVICE DEFAULT>',
-        :ssl_key_file          => '<SERVICE DEFAULT>',
-        :ssl_key_password      => '<SERVICE DEFAULT>',
-        :sasl_mechanisms       => '<SERVICE DEFAULT>',
-        :sasl_config_dir       => '<SERVICE DEFAULT>',
-        :sasl_config_name      => '<SERVICE DEFAULT>',
-        :username              => '<SERVICE DEFAULT>',
-        :password              => '<SERVICE DEFAULT>',
-      ) }
-    end
-
-    context 'with overridden amqp parameters' do
-      before { params.merge!(
-        :amqp_idle_timeout  => '60',
-        :amqp_trace         => true,
-        :amqp_ssl_ca_file   => '/path/to/ca.cert',
-        :amqp_ssl_cert_file => '/path/to/certfile',
-        :amqp_ssl_key_file  => '/path/to/key',
-        :amqp_username      => 'amqp_user',
-        :amqp_password      => 'password',
-      ) }
-
-      it { is_expected.to contain_oslo__messaging__amqp('heat_config').with(
-        :server_request_prefix => '<SERVICE DEFAULT>',
-        :broadcast_prefix      => '<SERVICE DEFAULT>',
-        :group_request_prefix  => '<SERVICE DEFAULT>',
-        :container_name        => '<SERVICE DEFAULT>',
-        :idle_timeout          => '60',
-        :trace                 => true,
-        :ssl_ca_file           => '/path/to/ca.cert',
-        :ssl_cert_file         => '/path/to/certfile',
-        :ssl_key_file          => '/path/to/key',
-        :ssl_key_password      => '<SERVICE DEFAULT>',
-        :sasl_mechanisms       => '<SERVICE DEFAULT>',
-        :sasl_config_dir       => '<SERVICE DEFAULT>',
-        :sasl_config_name      => '<SERVICE DEFAULT>',
-        :username              => 'amqp_user',
-        :password              => 'password',
-      ) }
-    end
-  end
-
   on_supported_os({
     :supported_os   => OSDefaults.get_supported_os
   }).each do |os,facts|
