@@ -17,12 +17,15 @@ describe 'heat::keystone::auth' do
         :configure_endpoint  => true,
         :service_name        => 'heat',
         :service_type        => 'orchestration',
-        :service_description => 'Openstack Orchestration Service',
+        :service_description => 'OpenStack Orchestration Service',
         :region              => 'RegionOne',
         :auth_name           => 'heat',
         :password            => 'heat_password',
         :email               => 'heat@localhost',
         :tenant              => 'services',
+        :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8004/v1/%(tenant_id)s',
         :internal_url        => 'http://127.0.0.1:8004/v1/%(tenant_id)s',
         :admin_url           => 'http://127.0.0.1:8004/v1/%(tenant_id)s',
@@ -38,10 +41,13 @@ describe 'heat::keystone::auth' do
           :auth_name                 => 'alt_heat',
           :email                     => 'alt_heat@alt_localhost',
           :tenant                    => 'alt_service',
+          :roles                     => ['admin', 'service'],
+          :system_scope              => 'alt_all',
+          :system_roles              => ['admin', 'member', 'reader'],
           :configure_endpoint        => false,
           :configure_user            => false,
           :configure_user_role       => false,
-          :service_description       => 'Alternative Openstack Orchestration Service',
+          :service_description       => 'Alternative OpenStack Orchestration Service',
           :service_name              => 'alt_service',
           :service_type              => 'alt_orchestration',
           :region                    => 'RegionTwo',
@@ -59,12 +65,15 @@ describe 'heat::keystone::auth' do
         :configure_endpoint  => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_orchestration',
-        :service_description => 'Alternative Openstack Orchestration Service',
+        :service_description => 'Alternative OpenStack Orchestration Service',
         :region              => 'RegionTwo',
         :auth_name           => 'alt_heat',
         :password            => 'heat_password',
         :email               => 'alt_heat@alt_localhost',
         :tenant              => 'alt_service',
+        :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
